@@ -33,10 +33,8 @@
 
 #include <iostream>
 #include <qinputdialog.h>
-#include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
-#include <kstandarddirs.h>
 #include <kservicetypetrader.h>
 #include <kiconloader.h>
 #include <kactioncollection.h>
@@ -52,7 +50,9 @@
 #include <QDomElement>
 #include <QApplication>
 #include <QClipboard>
+#include <QFileDialog>
 #include <QAbstractItemView>
+#include <QStandardPaths>
 #include <QTimer>
 #include <QTemporaryFile>
 
@@ -494,8 +494,14 @@ void KGet::load( QString filename ) // krazy:exclude=passbyvalue
 {
     qCDebug(KGET_DEBUG) << "(" << filename << ")";
 
-    if(filename.isEmpty())
-        filename = KStandardDirs::locateLocal("appdata", "transfers.kgt");
+    if(filename.isEmpty()) {
+        filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+        // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+        if (!QFileInfo::exists(filename)) {
+            QDir().mkpath(filename);
+        }
+        filename += QStringLiteral("/transfers.kgt");
+    }
 
     QTemporaryFile tmpFile;
 
@@ -572,8 +578,14 @@ void KGet::save( QString filename, bool plain ) // krazy:exclude=passbyvalue
                 != KMessageBox::Yes) )
         return;
 
-    if(filename.isEmpty())
-        filename = KStandardDirs::locateLocal("appdata", "transfers.kgt");
+    if(filename.isEmpty()) {
+        filename = QStandardPaths::writableLocation(QStandardPaths::DataLocation);
+        // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+        if (!QFileInfo::exists(filename)) {
+            QDir().mkpath(filename);
+        }
+        filename += QStringLiteral("/transfers.kgt");
+    }
     
     qCDebug(KGET_DEBUG) << "Save transferlist to " << filename;
 
@@ -969,7 +981,7 @@ QUrl KGet::urlInputDialog()
 
 QString KGet::destDirInputDialog()
 {
-    QString destDir = KFileDialog::getExistingDirectory(generalDestDir());
+    QString destDir = QFileDialog::getExistingDirectory(nullptr, i18nc("@title:window", "Choose Directory"), generalDestDir(), QFileDialog::ShowDirsOnly | QFileDialog::DontResolveSymlinks);
     Settings::setLastDirectory(destDir);
 
     return destDir;
@@ -988,7 +1000,7 @@ QUrl KGet::destFileInputDialog(QString destDir, const QString& suggestedFileName
         startLocation.setPath(destDir);
     }
 
-    QUrl destUrl = KFileDialog::getSaveUrl(startLocation, QString(), m_mainWindow, i18n("Save As"));
+    QUrl destUrl = QFileDialog::getSaveFileUrl(m_mainWindow, i18nc("@title:window", "Save As"), startLocation, QString());
     if (!destUrl.isEmpty()) {
         Settings::setLastDirectory(destUrl.adjusted(QUrl::RemoveFilename).path());
     }
