@@ -25,16 +25,17 @@
 
 #include <KIconLoader>
 #include <KIO/DeleteJob>
-#include <KIO/NetAccess>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QDebug>
-#include <KDialog>
-#include <KStandardDirs>
+#include <QDialog>
+
 
 #include <QFile>
 #include <QDomElement>
+#include <QStandardPaths>
+#include <KConfigGroup>
 
 Metalink::Metalink(TransferGroup * parent, TransferFactory * factory,
                          Scheduler * scheduler, const QUrl & source, const QUrl & dest,
@@ -78,7 +79,11 @@ void Metalink::downloadMetalink()
 
     setStatus(Job::Stopped, i18n("Downloading Metalink File...."), SmallIcon("document-save"));
     setTransferChange(Tc_Status, true);
-    Download *download = new Download(m_source, QString(KStandardDirs::locateLocal("appdata", "metalinks/") + m_source.fileName()));
+    // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+    if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::DataLocation))) {
+        QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+    }
+    Download *download = new Download(m_source, QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/metalinks/") + m_source.fileName());
     connect(download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(metalinkInit(QUrl,QByteArray)));
 }
 
@@ -203,7 +208,7 @@ bool Metalink::metalinkInit(const QUrl &src, const QByteArray &data)
     //the metalink-file has just been downloaded, so ask the user to choose the files that
     // should be downloaded
     if (m_metalinkJustDownloaded) {
-        KDialog *dialog = new FileSelectionDlg(fileModel());
+        QDialog *dialog = new FileSelectionDlg(fileModel());
         dialog->setAttribute(Qt::WA_DeleteOnClose);
         connect(dialog, SIGNAL(finished(int)), this, SLOT(fileDlgFinished(int)));
 
@@ -284,7 +289,9 @@ void Metalink::deinit(Transfer::DeleteOptions options)
     if ((options & Transfer::DeleteTemporaryFiles) && m_localMetalinkLocation.isLocalFile())
     {
         KIO::Job *del = KIO::del(m_localMetalinkLocation, KIO::HideProgressInfo);
-        KIO::NetAccess::synchronousRun(del, nullptr);
+        if (!del->exec()) {
+            qCDebug(KGET_DEBUG) << "Could not delete " << m_localMetalinkLocation.path();
+        }
     }
 
 }
@@ -706,7 +713,7 @@ void Metalink::filesSelected()
                     doDownload = false;
                 //ask the user, unless he has chosen overwriteAll before
                 } else if (!overwriteAll) {
-                    KIO::RenameDialog dlg(nullptr, i18n("File already exists"), index.data().toString(), dest, KIO::RenameDialog_Mode(KIO::M_MULTI | KIO::M_OVERWRITE | KIO::M_SKIP));
+                    KIO::RenameDialog dlg(nullptr, i18n("File already exists"), index.data().toString(), dest, KIO::RenameDialog_Options(KIO::RenameDialog_MultipleItems | KIO::RenameDialog_Overwrite | KIO::RenameDialog_Skip));
                     const int result = dlg.exec();
 
                     if (result == KIO::R_RENAME) {
