@@ -25,20 +25,20 @@
 #include "core/signature.h"
 
 #include "kget_debug.h"
-#include <qdebug.h>
 
 #include <KIconLoader>
 #include <KIO/DeleteJob>
-#include <KIO/NetAccess>
 #include <KIO/RenameDialog>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KDebug>
-#include <KDialog>
-#include <KStandardDirs>
+#include <QDialog>
+
 
 #include <QFile>
+#include <QDir>
 #include <QDomElement>
+#include <QStandardPaths>
+#include <KConfigGroup>
 
 MetalinkXml::MetalinkXml(TransferGroup * parent, TransferFactory * factory,
                          Scheduler * scheduler, const QUrl & source, const QUrl & dest,
@@ -76,7 +76,11 @@ void MetalinkXml::downloadMetalink()
 
     setStatus(Job::Running, i18n("Downloading Metalink File...."), SmallIcon("document-save"));
     setTransferChange(Tc_Status, true);
-    Download *download = new Download(m_source, QString(KStandardDirs::locateLocal("appdata", "metalinks/") + m_source.fileName()));
+    // make sure that the DataLocation directory exists (earlier this used to be handled by KStandardDirs)
+    if (!QFileInfo::exists(QStandardPaths::writableLocation(QStandardPaths::DataLocation))) {
+        QDir().mkpath(QStandardPaths::writableLocation(QStandardPaths::DataLocation));
+    }
+    Download *download = new Download(m_source, QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QStringLiteral("/metalinks/") + m_source.fileName());
     connect(download, SIGNAL(finishedSuccessfully(QUrl,QByteArray)), SLOT(metalinkInit(QUrl,QByteArray)));
 }
 
@@ -254,7 +258,9 @@ void MetalinkXml::deinit(Transfer::DeleteOptions options)
     if ((options & Transfer::DeleteTemporaryFiles) && m_localMetalinkLocation.isLocalFile())
     {
         KIO::Job *del = KIO::del(m_localMetalinkLocation, KIO::HideProgressInfo);
-        KIO::NetAccess::synchronousRun(del, nullptr);
+        if (!del->exec()) {
+            qCDebug(KGET_DEBUG) << "Could not delete " << m_localMetalinkLocation.path();
+        }
     }
 
 }
