@@ -24,41 +24,45 @@
 #include "core/transferhandler.h"
 #include "core/signature.h"
 
+
+#include "kget_debug.h"
+#include <qdebug.h>
+
 #ifdef HAVE_QGPGME
 #include <gpgme++/context.h>
 #include <gpgme++/key.h>
 #endif
 
-#include <QtGui/QLayoutItem>
+#include <QLayoutItem>
 
-#include <KFileDialog>
-#include <KLocale>
+#include <QFileDialog>
+#include <KLocalizedString>
+#include <KIconLoader>
 
 const QStringList SignatureDlg::OWNERTRUST = QStringList() << i18nc("trust level", "Unknown") << i18nc("trust level", "Undefined") << i18nc("trust level", "Never") << i18nc("trust level", "Marginal") << i18nc("trust level", "Full") << i18nc("trust level", "Ultimate");
 
-SignatureDlg::SignatureDlg(TransferHandler *transfer, const KUrl &dest, QWidget *parent, Qt::WFlags flags)
+SignatureDlg::SignatureDlg(TransferHandler *transfer, const QUrl &dest, QWidget *parent, Qt::WFlags flags)
   : KGetSaveSizeDialog("SignatureDlg", parent, flags),
     m_signature(transfer->signature(dest)),
     m_fileModel(transfer->fileModel())
 {
-    setCaption(i18nc("Signature here is meant in cryptographic terms, so the signature of a file.", "Signature of %1.", dest.fileName()));
-    QWidget *widget = new QWidget(this);
-    ui.setupUi(widget);
-    ui.loadSignature->setIcon(KIcon("document-open"));
-    ui.verify->setIcon(KIcon("document-encrypt"));
-    setMainWidget(widget);
+    setWindowTitle(i18nc("Signature here is meant in cryptographic terms, so the signature of a file.", "Signature of %1.", dest.fileName()));
+
+    ui.setupUi(this);
+    ui.loadSignature->setIcon(QIcon::fromTheme("document-open"));
+    ui.verify->setIcon(QIcon::fromTheme("document-encrypt"));
 
     ui.information->setCloseButtonVisible(false);
     ui.information->setWordWrap(true);
     if (m_signature) {
-        connect(ui.loadSignature, SIGNAL(clicked(bool)), this, SLOT(loadSignatureClicked()));
-        connect(ui.verify, SIGNAL(clicked()), this, SLOT(verifyClicked()));
-        connect(ui.signature, SIGNAL(textChanged()), this, SLOT(textChanged()));
-        connect(m_signature, SIGNAL(verified(int)), this, SLOT(updateData()));
+        connect(ui.loadSignature, &QPushButton::clicked, this, &SignatureDlg::loadSignatureClicked);
+        connect(ui.verify, &QPushButton::clicked, this, &SignatureDlg::verifyClicked);
+        connect(ui.signature, &KTextEdit::textChanged, this, &SignatureDlg::textChanged);
+        connect(m_signature, &Signature::verified, this, &SignatureDlg::updateData);
 
         if (m_fileModel) {
             m_file = m_fileModel->index(dest, FileItem::File);
-            connect(m_fileModel, SIGNAL(fileFinished(KUrl)), this, SLOT(fileFinished(KUrl)));
+            connect(m_fileModel, &FileModel::fileFinished, this, &SignatureDlg::fileFinished);
         }
 
         updateData();
@@ -69,9 +73,11 @@ SignatureDlg::SignatureDlg(TransferHandler *transfer, const KUrl &dest, QWidget
         ui.sigGroup->hide();
         ui.keyGroup->hide();
     }
+    connect(ui.buttonBox, &QDialogButtonBox::accepted, this, &QDialog::accept);
+    connect(ui.buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
 }
 
-void SignatureDlg::fileFinished(const KUrl &file)
+void SignatureDlg::fileFinished(const QUrl &file)
 {
     if (m_fileModel && (m_fileModel->getUrl(m_file) == file)) {
         updateButtons();
@@ -90,24 +96,24 @@ void SignatureDlg::textChanged()
 
 void SignatureDlg::loadSignatureClicked()
 {
-    const KUrl url = KFileDialog::getOpenUrl(KGet::generalDestDir(), "*.asc|" + i18n("Detached OpenPGP ASCII signature (*.asc)") + '\n' +
-                                             "*.sig|" + i18n("Detached OpenPGP binary signature (*.sig)"), this, i18n("Load Signature File"));
+    const QUrl url = QFileDialog::getOpenFileUrl(this, i18n("Load Signature File"), KGet::generalDestDir(), "*.asc|" + i18n("Detached OpenPGP ASCII signature (*.asc)") + '\n' +
+                                             "*.sig|" + i18n("Detached OpenPGP binary signature (*.sig)"));
     if (url.isEmpty()) {
         return;
     }
 
-    const bool isAsciiSig = url.fileName().endsWith("asc");
+    const bool isAsciiSig = url.fileName().endsWith(QLatin1String(".asc"));
     clearData();
     handleWidgets(isAsciiSig);
     ui.signature->clear();
 
     QFile file(url.path());
     if (!file.open(QIODevice::ReadOnly)) {
-        kWarning(5001) << "Could not open file" << url;
+        qCWarning(KGET_DEBUG) << "Could not open file" << url;
         return;
     }
     if (file.size() > 1 * 1024) {
-        kWarning(5001) << "File is larger than 1 KiB, which is not supported.";
+        qCWarning(KGET_DEBUG) << "File is larger than 1 KiB, which is not supported.";
         return;
     }
 
@@ -172,14 +178,14 @@ void SignatureDlg::updateData()
         GpgME::Error err = GpgME::checkEngine(GpgME::OpenPGP);
         QScopedPointer<GpgME::Context> context(GpgME::Context::createForProtocol(GpgME::OpenPGP));
         if (err) {
-            kDebug(5001) << "OpenPGP not supported!";
+            qCDebug(KGET_DEBUG) << "OpenPGP not supported!";
         } else if (!context.data()) {
-                kDebug(5001) << "Could not create context.";
+                qCDebug(KGET_DEBUG) << "Could not create context.";
         } else {
             QByteArray fingerprint = fingerprintString.toAscii();
             const GpgME::Key key = context->key(fingerprint.constData(), err);
             if (err || key.isNull() || !key.numUserIDs() || !key.numSubkeys()) {
-                kDebug(5001) << "There was an error while loading the key:" << err;
+                qCDebug(KGET_DEBUG) << "There was an error while loading the key:" << err;
             } else {
                 if (key.isRevoked()) {
                     information << i18n("The key has been revoked.");
@@ -196,7 +202,7 @@ void SignatureDlg::updateData()
                 ui.expirationIcon->clear();
                 if (key.isExpired()) {
                     information << i18n("The key is expired.");
-                    ui.expirationIcon->setPixmap(KIcon("dialog-warning").pixmap(iconSize));
+                    ui.expirationIcon->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(iconSize));
                     ui.expirationIcon->show();
                     problem = true;
                 } else {
@@ -211,25 +217,25 @@ void SignatureDlg::updateData()
                 switch (ownerTrust) {
                     case GpgME::Key::Never:
                         information.prepend(i18n("The key is not to be trusted."));
-                        ui.trustIcon->setPixmap(KIcon("dialog-error").pixmap(iconSize));
+                        ui.trustIcon->setPixmap(QIcon::fromTheme("dialog-error").pixmap(iconSize));
                         error = true;
                         break;
                     case GpgME::Key::Marginal:
                         information.prepend(i18n("The key is to be trusted marginally."));
-                        ui.trustIcon->setPixmap(KIcon("dialog-warning").pixmap(iconSize));
+                        ui.trustIcon->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(iconSize));
                         problem = true;
                         break;
                     case GpgME::Key::Full:
-                        ui.trustIcon->setPixmap(KIcon("dialog-ok").pixmap(iconSize));
+                        ui.trustIcon->setPixmap(QIcon::fromTheme("dialog-ok").pixmap(iconSize));
                         break;
                     case GpgME::Key::Ultimate:
-                        ui.trustIcon->setPixmap(KIcon("dialog-ok").pixmap(iconSize));
+                        ui.trustIcon->setPixmap(QIcon::fromTheme("dialog-ok").pixmap(iconSize));
                         break;
                     case GpgME::Key::Unknown:
                     case GpgME::Key::Undefined:
                     default:
                         information.prepend(i18n("Trust level of the key is unclear."));
-                        ui.trustIcon->setPixmap(KIcon("dialog-warning").pixmap(iconSize));
+                        ui.trustIcon->setPixmap(QIcon::fromTheme("dialog-warning").pixmap(iconSize));
                         problem = true;
                         break;
                 }
@@ -273,13 +279,13 @@ void SignatureDlg::updateData()
         case Signature::Verified:
         case Signature::VerifiedInformation:
         case Signature::VerifiedWarning:
-            ui.verificationIcon->setPixmap(KIcon("dialog-ok").pixmap(iconSize));
+            ui.verificationIcon->setPixmap(QIcon::fromTheme("dialog-ok").pixmap(iconSize));
             ui.verificationIcon->show();
             ui.verified->setText(i18nc("pgp signature is verified", "Verified"));
             break;
         case Signature::NotVerified:
             ui.verified->setText(i18nc("pgp signature is not verified", "Failed"));
-            ui.verificationIcon->setPixmap(KIcon("dialog-error").pixmap(iconSize));
+            ui.verificationIcon->setPixmap(QIcon::fromTheme("dialog-error").pixmap(iconSize));
             ui.verificationIcon->show();
             information.prepend(i18n("Caution: Verification failed. Either you entered the wrong signature, or the data has been modified."));
             error = true;
@@ -365,4 +371,4 @@ void SignatureDlg::handleWidgets(bool isAsciiSig)
     }
 }
 
-#include "signaturedlg.moc"
+
